package DVDzbr_rest::Model::DBICSchemamodel;

use strict;
use base 'Catalyst::Model::DBIC::Schema';

__PACKAGE__->config(
    schema_class => 'DVDzbr_rest::DBSchema',
    
    
);

=head1 NAME

DVDzbr_rest::Model::DBICSchemamodel - Catalyst DBIC Schema Model

=head1 SYNOPSIS

See L<DVDzbr_rest>

=head1 DESCRIPTION

L<Catalyst::Model::DBIC::Schema> Model using schema L<DVDzbr_rest::DBSchema>

=head1 GENERATED BY

Catalyst::Helper::Model::DBIC::Schema - 0.41

=head1 AUTHOR

User &

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
